#
# spec file for package zvm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zvm
Version:        0.8.7
Release:        1.1
Summary:        Easily install/upgrade between different versions of Zig
License:        MIT
URL:            https://github.com/tristanisham/zvm
Source:         https://github.com/tristanisham/zvm/archive/refs/tags/v%{version}.tar.gz
Source1:        vendor.tar.xz
# PATCH-FIX-UPSTREAM: Disable auto upgrade features
Patch0:         disable-auto-upgrade.patch
BuildRequires:  golang(API) >= 1.22

%description
Zig Version Manager (zvm) is a tool for managing your Zig installs. With std
under heavy development and a large feature roadmap, Zig is bound to continue
changing. Breaking existing builds, updating valid syntax, and introducing new
features like a package manager. While this is great for developers, it also
can lead to headaches when you need multiple versions of a language installed
to compile your projects, or a language gets updated frequently.

%prep
%autosetup -p1 -a1 -n zvm-%{version}

%build
go build \
   -ldflags="-s -w" \
   -mod=vendor \
   -buildmode=pie \
   -v

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%check
go test ./cli -v

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Mon May 26 2025 Lucas Mulling <lucas.mulling@suse.com>
- Update to 0.8.7:
  * Fixed issue when running vmu zig mach on a clean install
* Sat Apr  5 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.8.6:
  * skip flag parsing with zvm run by @vrischmann in #123
  * Add check for 32-bit arch as there is no release for it. by @geouno in #128
- fixed changelog version
* Fri Feb 14 2025 Lucas Mulling <lucas.mulling@suse.com>
- Update to 0.8.5:
  * Updating year to 2025 in main.go and LICENSE file,just a small pedant… by
    @bq-wrongway in #114
  * Use --zls In any location by @Jaxon-teBoekhorst in #112
- Rebase patch disable-auto-upgrade.patch
* Fri Jan 17 2025 Lucas Mulling <lucas.mulling@suse.com>
- Update to 0.8.4 includes changes from 0.8.3:
  * add loongarch64 by @candicandi in #109
  * add powerpc64le
- Add patch
  * disable-auto-upgrade.patch
* Fri Dec 27 2024 Lucas Mulling <lucas.mulling@suse.com>
- Initial package of version: 0.8.2
  * For the full changelog see: https://github.com/tristanisham/zvm/releases
